pub fn format_venue_symbol(instrument_id: &InstrumentId) -> &str
Returns the venue-native symbol for an instrument id by stripping any known product suffix. Returns the raw symbol unchanged when no suffix is present.